==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/pages_17.js <==
var searchData=
[
  ['range_20operations_0',['Range operations',['../classgko_1_1range.html#autotoc_md77',1,'']]],
  ['ranges_20program_1',['The ginkgo-ranges program',['../ginkgo_ranges.html',1,'']]],
  ['refinement_20program_2',['The iterative-refinement program',['../iterative_refinement.html',1,'']]],
  ['related_3',['Git related',['../contributing_guidelines.html#autotoc_md23',1,'']]],
  ['reordered_20preconditioned_20solver_20program_4',['The reordered-preconditioned-solver program',['../reordered_preconditioned_solver.html',1,'']]],
  ['requests_5',['Creating, Reviewing and Merging Pull Requests',['../contributing_guidelines.html#autotoc_md27',1,'']]],
  ['results_20on_20github_20and_20analyze_20the_20results_20with_20the_20gpe_20optional_6',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
  ['results_20with_20the_20gpe_20optional_7',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
  ['reviewing_20and_20merging_20pull_20requests_8',['Creating, Reviewing and Merging Pull Requests',['../contributing_guidelines.html#autotoc_md27',1,'']]],
  ['rules_9',['Some general rules.',['../contributing_guidelines.html#autotoc_md56',1,'']]],
  ['running_20benchmarks_20manually_10',['3: Running benchmarks manually',['../benchmarking_ginkgo.html#autotoc_md13',1,'']]],
  ['running_20the_20benchmarks_11',['Running the benchmarks',['../benchmarking_ginkgo.html',1,'']]],
  ['running_20the_20unit_20tests_12',['Running the unit tests',['../testing_ginkgo.html#autotoc_md7',1,'']]]
];

==> ginkgo-hpc-docs-1.11.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/pages_17.js <==
var searchData=
[
  ['range_20operations_0',['Range operations',['../classgko_1_1range.html#autotoc_md77',1,'']]],
  ['ranges_20program_1',['The ginkgo-ranges program',['../ginkgo_ranges.html',1,'']]],
  ['refinement_20program_2',['The iterative-refinement program',['../iterative_refinement.html',1,'']]],
  ['related_3',['Git related',['../contributing_guidelines.html#autotoc_md23',1,'']]],
  ['reordered_20preconditioned_20solver_20program_4',['The reordered-preconditioned-solver program',['../reordered_preconditioned_solver.html',1,'']]],
  ['requests_5',['Creating, Reviewing and Merging Pull Requests',['../contributing_guidelines.html#autotoc_md27',1,'']]],
  ['results_20on_20github_20and_20analyze_20the_20results_20with_20the_20gpe_20optional_6',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
  ['results_20with_20the_20gpe_20optional_7',['5: Publishing the results on Github and analyze the results with the GPE (optional)',['../benchmarking_ginkgo.html#autotoc_md15',1,'']]],
  ['reviewing_20and_20merging_20pull_20requests_8',['Creating, Reviewing and Merging Pull Requests',['../contributing_guidelines.html#autotoc_md27',1,'']]],
  ['rules_9',['Some general rules.',['../contributing_guidelines.html#autotoc_md56',1,'']]],
  ['run_5fall_5fbenchmarks_20sh_10',['4: Benchmarking with &lt;span class=&quot;tt&quot;&gt;make benchmark&lt;/span&gt; or &lt;span class=&quot;tt&quot;&gt;run_all_benchmarks.sh&lt;/span&gt;',['../benchmarking_ginkgo.html#autotoc_md14',1,'']]],
  ['running_20benchmarks_20manually_11',['3: Running benchmarks manually',['../benchmarking_ginkgo.html#autotoc_md13',1,'']]],
  ['running_20the_20benchmarks_12',['Running the benchmarks',['../benchmarking_ginkgo.html',1,'']]],
  ['running_20the_20unit_20tests_13',['Running the unit tests',['../testing_ginkgo.html#autotoc_md7',1,'']]]
];
